@@ -1,7 +1,7 @@
 __version_info__ = {
     'major': 0,
     'minor': 9,
-    'micro': 2,
+    'micro': 3,
     'releaselevel': 'final',
     'serial': 1
 }
@@ -20,4 +20,4 @@ __version__ = get_version()
 
 
 from .graph import Node, Nodes, Rel, Rels  # noqa
-from .serialize import serialize, Serializer  # noqa
+from .serializer import serialize, Serializer  # noqa
